summaryrefslogtreecommitdiff
path: root/python/binaryview.py
diff options
context:
space:
mode:
authorJordan Wiens <jordan@psifertex.com>2019-09-26 18:02:50 -0400
committerJordan Wiens <jordan@psifertex.com>2019-09-26 18:02:50 -0400
commitc00e2e304e548ab03a69e81ce46e76772adc0ccd (patch)
tree5c628b8e61760951bcbbf78e1280a5746823f4a8 /python/binaryview.py
parentd3ea4e78e70dbab7c813f52f7a7f164465474a02 (diff)
more small documentation fixes
Diffstat (limited to 'python/binaryview.py')
-rw-r--r--python/binaryview.py13
1 files changed, 6 insertions, 7 deletions
diff --git a/python/binaryview.py b/python/binaryview.py
index b45b89ba..7ff4d4cf 100644
--- a/python/binaryview.py
+++ b/python/binaryview.py
@@ -4832,7 +4832,7 @@ class BinaryView(object):
"""
``show_markdown_report`` displays the markdown contents in UI applications and plaintext in command-line
applications. Markdown reports support hyperlinking into the BinaryView. Hyperlinks can be specified as follows:
- ``binaryninja://?expr=_start`` Where ``expr=`` specifies an expression parsable by the `parse_expression` API.
+ ``binaryninja://?expr=_start`` Where ``expr=`` specifies an expression parsable by the :py:meth:`parse_expression` API.
Note: This API function differently on the command-line vs the UI. In the UI a pop-up is used. On the command-line \
a simple text prompt is used.
@@ -4850,7 +4850,7 @@ class BinaryView(object):
"""
``show_html_report`` displays the HTML contents in UI applications and plaintext in command-line
applications. HTML reports support hyperlinking into the BinaryView. Hyperlinks can be specified as follows:
- ``binaryninja://?expr=_start`` Where ``expr=`` specifies an expression parsable by the `parse_expression` API.
+ ``binaryninja://?expr=_start`` Where ``expr=`` specifies an expression parsable by the :py:meth:`parse_expression` API.
Note: This API function differently on the command-line vs the UI. In the UI a pop-up is used. On the command-line \
a simple text prompt is used.
@@ -5112,11 +5112,11 @@ class BinaryView(object):
- Symbols are everything in ``bv.symbols``, unnamed DataVariables (i.e. ``data_00005000``), unnamed functions (i.e. ``sub_00005000``), or section names (i.e. ``.text``)
- Numbers are defaulted to hexadecimal thus `_printf + 10` is equivalent to `printf + 0x10` If decimal numbers required use the decimal prefix.
- Since numbers and symbols can be ambiguous its recommended that you prefix your numbers with the following:
-
+
- ``0x`` - Hexadecimal
- ``0n`` - Decimal
- ``0`` - Octal
-
+
- In the case of an ambiguous number/symbol (one with no prefix) for instance ``12345`` we will first attempt
to look up the string as a symbol, if a symbol is found its address is used, otherwise we attempt to convert
it to a hexadecimal number.
@@ -5128,7 +5128,7 @@ class BinaryView(object):
- ``[<expression>].w`` - read the word (2 bytes) at ``<expression>``
- ``[<expression>].d`` - read the dword (4 bytes) at ``<expression>``
- ``[<expression>].q`` - read the quadword (8 bytes) at ``<expression>``
-
+
- The ``$here`` keyword can be used in calculations and is defined as the ``here`` parameter
- The ``$start``/``$end`` keyword represents the address of the first/last bytes in the file respectively
@@ -5146,8 +5146,7 @@ class BinaryView(object):
def eval(self, expression, here=0):
"""
Evaluates an string expression to an integer value. This is a more concise alias for the `parse_expression` API
See `parse_expression` for details on usage.
"""
return self.parse_expression(expression, here)
@@ -5146,8 +5146,7 @@ class BinaryView(object):
def eval(self, expression, here=0):
"""
- Evaluates an string expression to an integer value. This is a more concise alias for the `parse_expression` API
- See `parse_expression` for details on usage.
+ Evaluates an string expression to an integer value. This is a more concise alias for the :py:meth:`parse_expression` API
"""
return self.parse_expression(expression, here)